/*
 * ============================================================================
 * Licensed Materials - Property of IBM
 * Project  Zero
 *
 * (C) Copyright IBM Corp. 2007  All Rights Reserved.
 *
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 * ============================================================================
 */
 
import zero.resource.TypeCollection
import zero.resource.exceptions.*

def onList() {
    def types = TypeCollection.list()
    types = types.collect { type ->
        makeTypeHash(type)
    }
    outputJson(types)
}

def onRetrieve() {
    def id = request.params.typesId[]
    try {
        def result = TypeCollection.retrieve(id)
        result = makeTypeHash(result)
        outputJson(result)
    } catch (TypeDoesNotExistException e) {
        send404(e)
    }
}

def makeTypeHash(type) {
    def hash = [type: type.typeName]
    def fields = [:]
    type.fields.each { field_name, field_spec ->
        def map = field_spec.toMap()
        fields[field_name] = map
    }
    hash.fields = fields
    return hash
}

def send404(e) {
    logger.FINEST {"404 -> ${e.message}"}
    request.status = HttpURLConnection.HTTP_NOT_FOUND
    request.view = "error"
    render()
}


def outputJson(data) {
    logger.FINEST {"type metadata -> $data"}
    request.view = 'JSON'
    request.json.output = data
    render()
}